@@ -1,15 +1,22 @@
 import mimetypes
 import os
+from io import BytesIO
+from pathlib import Path
 
 from django.conf import settings
 from django.contrib.contenttypes.fields import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
+from django.core.files import File
+from django.core.files.base import ContentFile
 from django.db import models
 from django.template.defaultfilters import slugify
 from django.utils.translation import gettext_lazy as _
 from embed_video.fields import EmbedVideoField
+from PIL import Image
 
-from paperclip.settings import PAPERCLIP_ENABLE_VIDEO, PAPERCLIP_FILETYPE_MODEL, PAPERCLIP_ENABLE_LINK
+from paperclip.settings import (PAPERCLIP_ENABLE_LINK, PAPERCLIP_ENABLE_VIDEO,
+                                PAPERCLIP_FILETYPE_MODEL, PAPERCLIP_MAX_ATTACHMENT_HEIGHT,
+                                PAPERCLIP_MAX_ATTACHMENT_WIDTH, PAPERCLIP_RESIZE_ATTACHMENTS_ON_UPLOAD)
 
 
 class FileType(models.Model):
@@ -93,9 +100,25 @@ class Attachment(models.Model):
     date_update = models.DateTimeField(editable=False, auto_now=True,
                                        verbose_name=_("Update date"))
 
-    def save(self, **kwargs):
+    def save(self, *args, **kwargs):
         self.is_image = self.is_an_image()
-        super().save(**kwargs)
+        if PAPERCLIP_RESIZE_ATTACHMENTS_ON_UPLOAD and self.is_image and self.attachment_file:
+            # Resize image
+            image = Image.open(self.attachment_file).convert('RGB')
+            image.thumbnail((PAPERCLIP_MAX_ATTACHMENT_WIDTH, PAPERCLIP_MAX_ATTACHMENT_HEIGHT))
+            # Write resized image
+            output = BytesIO()
+            ext = Path(self.attachment_file.name).suffix.split('.')[-1]  # JPEG, PNG..
+            if ext == 'jpg' or ext == 'JPG':  # PIL does not know JPGs are JPEGs
+                ext = 'jpeg'
+            image.save(output, format=ext)
+            output.seek(0)
+            # Replace attachment
+            content_file = ContentFile(output.read())
+            file = File(content_file)
+            name = self.attachment_file.name
+            self.attachment_file.save(name, file, save=False)
+        super().save(*args, **kwargs)
 
     class Meta:
         abstract = True
