@@ -1,17 +1,44 @@
 import mimetypes
 
 from django.template import Library, Node, Variable
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from paperclip.forms import AttachmentForm
-from paperclip.models import Attachment
-from paperclip import app_settings
-
-USE_CRISPY_FORMS = app_settings['USE_CRISPY_FORMS']
+from paperclip import settings
 
 register = Library()
 
 
+@register.filter
+def read_attachment(perms):
+    perm = settings.get_attachment_permission('read_attachment')
+    return perm in perms
+
+
+@register.filter
+def add_attachment(perms):
+    perm = settings.get_attachment_permission('add_attachment')
+    return perm in perms
+
+
+@register.filter
+def delete_attachment(perms):
+    perm = settings.get_attachment_permission('delete_attachment')
+    return perm in perms
+
+
+@register.filter
+def change_attachment(perms):
+    perm = settings.get_attachment_permission('change_attachment')
+    return perm in perms
+
+
+@register.filter
+def delete_attachment_others(perms):
+    perm = settings.get_attachment_permission('delete_attachment_others')
+    return perm in perms
+
+
 @register.filter
 def icon_name(value):
     mimetype = value.mimetype
@@ -21,22 +48,22 @@ def icon_name(value):
     return ext[1:] if ext else 'bin'
 
 
-if USE_CRISPY_FORMS:
-    attachment_form_tpl_name = 'paperclip/_attachment_form.html'
-else:
-    attachment_form_tpl_name = 'paperclip/_attachment_form_no_crispy.html'
-
-
-@register.inclusion_tag(attachment_form_tpl_name, takes_context=True)
+@register.inclusion_tag('paperclip/_attachment_form.html', takes_context=True)
 def attachment_form(context, obj, form=None):
     """
-    Renders a "upload attachment" form.
+    Renders a "upload attachment" form. `obj` argument is required and
+    represents the instance to which you want to associate the file.
+    A bound form can be given optionnaly with the argument ``form``.
+    Important : a ``attachment_form_next`` variable is expected in context.
+    If you want to use a custom form class, you can add
+    ``attachment_form_class`` variable in context too
     """
     # Unbound form by default (this is why a template tag is used!)
     if form is None:
         request = context['request']
         next_url = context['attachment_form_next']
-        form = AttachmentForm(request, object=obj, next_url=next_url)
+        form_class = context.get('attachment_form_class', AttachmentForm)
+        form = form_class(request, object=obj, next_url=next_url)
 
     form_title = _("New file attachment")
     if form.instance.pk:
@@ -76,7 +103,7 @@ class AttachmentsForObjectNode(Node):
             method = 'attachments_for_object'
             args = [obj]
 
-        context[var_name] = getattr(Attachment.objects, method)(*args)
+        context[var_name] = getattr(settings.get_attachment_model().objects, method)(*args)
         return ''
 
 
@@ -100,7 +127,7 @@ def get_attachments_for(parser, token):
     """
     def next_bit_for(bits, key, if_none=None):
         try:
-            return bits[bits.index(key)+1]
+            return bits[bits.index(key) + 1]
         except ValueError:
             return if_none
 
